@@ -29,10 +29,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Controller class for forum sections
  */
-class ForumControllerSections extends \Hubzero\Component\AdminController
+class ForumControllerSections extends Hubzero_Controller
 {
 	/**
 	 * Display all sections
@@ -48,62 +50,62 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 		// Filters
 		$this->view->filters = array();
 		$this->view->filters['limit']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limit',
-			'limit',
-			$config->getValue('config.list_limit'),
+			$this->_option . '.' . $this->_controller . '.limit', 
+			'limit', 
+			$config->getValue('config.list_limit'), 
 			'int'
 		);
 		$this->view->filters['start']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limitstart',
-			'limitstart',
-			0,
+			$this->_option . '.' . $this->_controller . '.limitstart', 
+			'limitstart', 
+			0, 
+			'int'
+		);
+		$this->view->filters['group']    = $app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.group', 
+			'group', 
+			-1,
 			'int'
 		);
 		$this->view->filters['sort']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort',
-			'filter_order',
+			$this->_option . '.' . $this->_controller . '.sort', 
+			'filter_order', 
 			'id'
 		));
 		$this->view->filters['sort_Dir'] = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sortdir',
-			'filter_order_Dir',
+			$this->_option . '.' . $this->_controller . '.sortdir', 
+			'filter_order_Dir', 
 			'DESC'
 		));
-		$this->view->filters['scopeinfo']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.scopeinfo',
-			'scopeinfo',
-			''
-		));
-		if (strstr($this->view->filters['scopeinfo'], ':'))
-		{
-			$bits = explode(':', $this->view->filters['scopeinfo']);
-			$this->view->filters['scope'] = $bits[0];
-			$this->view->filters['scope_id'] = intval(end($bits));
-		}
-		else
-		{
-			$this->view->filters['scope'] = '';
-			$this->view->filters['scope_id'] = -1;
-		}
-
-		$model = new ForumModel($this->view->filters['scope'], $this->view->filters['scope_id']);
 
+		$model = new ForumSection($this->database);
+		
 		// Get a record count
-		$this->view->total = $model->sections('count', $this->view->filters);
+		$this->view->total = $model->getCount($this->view->filters);
 
 		// Get records
-		$this->view->results = $model->sections('list', $this->view->filters);
+		$this->view->results = $model->getRecords($this->view->filters);
+		if ($this->view->results)
+		{
+			$category = new ForumCategory($this->database);
+			foreach ($this->view->results as $key => $section)
+			{
+				$this->view->filters['section_id'] = $section->id;
+
+				$this->view->results[$key]->categories = $category->getCount($this->view->filters);
+			}
+		}
 
 		// initiate paging
 		jimport('joomla.html.pagination');
 		$this->view->pageNav = new JPagination(
-			$this->view->total,
-			$this->view->filters['start'],
+			$this->view->total, 
+			$this->view->filters['start'], 
 			$this->view->filters['limit']
 		);
 
 		// Set any errors
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			$this->view->setError($this->getError());
 		}
@@ -131,52 +133,40 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 	{
 		JRequest::setVar('hidemainmenu', 1);
 
+		$this->view->setLayout('edit');
+
+		// Incoming
+		$ids = JRequest::getVar('id', array());
+		if (is_array($ids) && !empty($ids)) 
+		{
+			$id = intval($ids[0]);
+		}
+
 		if (is_object($row))
 		{
 			$this->view->row = $row;
 		}
-		else
+		else 
 		{
-			$id = JRequest::getVar('id', array(0));
-			if (is_array($id))
-			{
-				$id = (!empty($id) ? intval($id[0]) : 0);
-			}
-
 			// load infor from database
-			$this->view->row = new ForumModelSection($id);
+			$this->view->row = new ForumSection($this->database);
+			$this->view->row->load($id);
 		}
 
-		if (!$this->view->row->exists())
+		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
-			$this->view->row->set('created_by', $this->juser->get('id'));
+			$m = new ForumModelSection();
+			$this->view->form = $m->getForm();
 		}
 
-		JFactory::getApplication()->setUserState('com_forum.edit.section.data', array(
-			'id'       => $this->view->row->get('id'),
-			'asset_id' => $this->view->row->get('asset_id')
-		));
-		$m = new ForumModelAdminSection();
-		$this->view->form = $m->getForm();
-
 		// Set any errors
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			$this->view->setError($this->getError());
 		}
-
+		
 		// Output the HTML
-		$this->view->setLayout('edit')->display();
-	}
-
-	/**
-	 * Save an entry and show the edit form
-	 *
-	 * @return     void
-	 */
-	public function applyTask()
-	{
-		$this->saveTask(false);
+		$this->view->display();
 	}
 
 	/**
@@ -184,31 +174,26 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 	 *
 	 * @return	void
 	 */
-	public function saveTask($redirect=true)
+	public function saveTask() 
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
-
-		JFactory::getApplication()->setUserState('com_forum.edit.section.data', null);
-
+		
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post');
 		$fields = array_map('trim', $fields);
 
-		// Bind the rules.
-		$data = JRequest::getVar('jform', array(), 'post');
-		if (isset($data['rules']) && is_array($data['rules']))
-		{
-			$model = new ForumModelAdminSection();
-			$form = $model->getForm($data, false);
-			$validData = $model->validate($form, $data);
-
-			$fields['rules'] = $validData['rules'];
-		}
-
 		// Initiate extended database class
-		$row = new ForumModelSection($fields['id']);
-		if (!$row->bind($fields))
+		$row = new ForumSection($this->database);
+		if (!$row->bind($fields)) 
+		{
+			$this->addComponentMessage($row->getError(), 'error');
+			$this->editTask($row);
+			return;
+		}
+		
+		// Check content
+		if (!$row->check()) 
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->editTask($row);
@@ -216,75 +201,70 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 		}
 
 		// Store content
-		if (!$row->store(true))
+		if (!$row->store()) 
 		{
 			$this->addComponentMessage($row->getError(), 'error');
 			$this->editTask($row);
 			return;
 		}
 
-		if ($redirect)
-		{
-			// Redirect
-			$this->setRedirect(
-				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_FORUM_SECTION_SAVED'),
-				'message'
-			);
-		}
-
-		$this->editTask($row);
+		// Redirect
+		$this->setRedirect(
+			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
+			JText::_('Section Successfully Saved'),
+			'message'
+		);
 	}
 
 	/**
 	 * Deletes one or more records and redirects to listing
-	 *
+	 * 
 	 * @return     void
 	 */
-	public function removeTask()
+	public function removeTask() 
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Incoming
+		$section = JRequest::getInt('section_id', 0);
 		$ids = JRequest::getVar('id', array());
-		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Do we have any IDs?
-		if (count($ids) > 0)
+		if (count($ids) > 0) 
 		{
 			// Loop through each ID
-			foreach ($ids as $id)
+			foreach ($ids as $id) 
 			{
 				$id = intval($id);
 
-				$section = new ForumTableSection($this->database);
+				$section = new ForumSection($this->database);
 				$section->load($id);
 
 				// Get the categories in this section
-				$cModel = new ForumTableCategory($this->database);
+				$cModel = new ForumCategory($this->database);
 				$categories = $cModel->getRecords(array('section_id' => $section->id));
 
 				// Loop through each category
 				foreach ($categories as $category)
 				{
 					// Remove the posts in this category
-					$tModel = new ForumTablePost($this->database);
-					if (!$tModel->deleteByCategory($category->id))
+					$tModel = new ForumPost($this->database);
+					if (!$tModel->deleteByCategory($category->id)) 
 					{
 						JError::raiseError(500, $tModel->getError());
 						return;
 					}
 					// Remove this category
-					if (!$cModel->delete($category->id))
+					if (!$cModel->delete($category->id)) 
 					{
-						JError::raiseError(500, $cModel->getError());
+						JError::raiseError(500, $category->getError());
 						return;
 					}
 				}
 
 				// Remove this section
-				if (!$section->delete())
+				if (!$section->delete()) 
 				{
 					JError::raiseError(500, $section->getError());
 					return;
@@ -294,14 +274,14 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 
 		// Redirect
 		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&section_id=' . JRequest::getInt('section_id', 0),
-			JText::_('COM_FORUM_SECTIONS_DELETED')
+			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&section_id=' . $section,
+			JText::_('Sections Successfully Removed')
 		);
 	}
 
 	/**
 	 * Calls stateTask to publish entries
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function publishTask()
@@ -311,7 +291,7 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 
 	/**
 	 * Calls stateTask to unpublish entries
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function unpublishTask()
@@ -321,43 +301,38 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 
 	/**
 	 * Sets the state of one or more entries
-	 *
+	 * 
 	 * @param      integer The state to set entries to
 	 * @return     void
 	 */
-	public function stateTask($state=0)
+	public function stateTask($state=0) 
 	{
 		// Check for request forgeries
-		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
-
+		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		
 		// Incoming
 		$ids = JRequest::getVar('id', array());
-		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Check for an ID
-		if (count($ids) < 1)
+		if (count($ids) < 1) 
 		{
-			$action = ($state == 1) ? JText::_('COM_FORUM_UNPUBLISH') : JText::_('COM_FORUM_PUBLISH');
+			$action = ($state == 1) ? JText::_('unpublish') : JText::_('publish');
 
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::sprintf('COM_FORUM_SELECT_ENTRY_TO', $action),
+				JText::_('Select an entry to ' . $action),
 				'error'
 			);
 			return;
 		}
 
-		foreach ($ids as $id)
+		foreach ($ids as $id) 
 		{
 			// Update record(s)
-			$row = new ForumModelSection(intval($id));
-			if (!$row->exists())
-			{
-				continue;
-			}
-
-			$row->set('state', $state);
-			if (!$row->store())
+			$row = new ForumSection($this->database);
+			$row->load(intval($id));
+			$row->state = $state;
+			if (!$row->store()) 
 			{
 				JError::raiseError(500, $row->getError());
 				return;
@@ -365,13 +340,13 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 		}
 
 		// set message
-		if ($state == 1)
+		if ($state == 1) 
 		{
-			$message = JText::sprintf('COM_FORUM_ITEMS_PUBLISHED', count($ids));
-		}
+			$message = JText::_(count($ids) . ' Item(s) successfully published');
+		} 
 		else
 		{
-			$message = JText::sprintf('COM_FORUM_ITEMS_UNPUBLISHED', count($ids));
+			$message = JText::_(count($ids) . ' Item(s) successfully unpublished');
 		}
 
 		$this->setRedirect(
@@ -382,42 +357,37 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 
 	/**
 	 * Sets the state of one or more entries
-	 *
+	 * 
 	 * @param      integer The state to set entries to
 	 * @return     void
 	 */
-	public function accessTask()
+	public function accessTask() 
 	{
 		// Check for request forgeries
-		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
-
+		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		
 		// Incoming
 		$state = JRequest::getInt('access', 0);
 		$ids = JRequest::getVar('id', array());
-		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Check for an ID
-		if (count($ids) < 1)
+		if (count($ids) < 1) 
 		{
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_FORUM_SELECT_ENTRY_TO_CHANGE_ACCESS'),
+				JText::_('Select an entry to change access'),
 				'error'
 			);
 			return;
 		}
 
-		foreach ($ids as $id)
+		foreach ($ids as $id) 
 		{
 			// Update record(s)
-			$row = new ForumModelSection(intval($id));
-			if (!$row->exists())
-			{
-				continue;
-			}
-
-			$row->set('access', $state);
-			if (!$row->store())
+			$row = new ForumSection($this->database);
+			$row->load(intval($id));
+			$row->access = $state;
+			if (!$row->store()) 
 			{
 				JError::raiseError(500, $row->getError());
 				return;
@@ -427,17 +397,19 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 		// set message
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::sprintf('COM_FORUM_ITEMS_ACCESS_CHANGED', count($ids))
+			JText::_(count($ids) . ' Item(s) successfully changed access')
 		);
 	}
 
 	/**
 	 * Cancels a task and redirects to listing
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function cancelTask()
 	{
+		$section = JRequest::getInt('section_id', 0);
+
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller
 		);
