@@ -2,15 +2,6 @@
 // No direct access
 defined('_JEXEC') or die( 'Restricted access' );
 
-$dateFormat = '%d %b. %Y';
-$tz = null;
-
-if (version_compare(JVERSION, '1.6', 'ge'))
-{
-	$dateFormat = 'd M. Y';
-	$tz = false;
-}
-
 JToolBarHelper::title( JText::_( 'Projects' ), 'user.png' );
 JToolBarHelper::preferences('com_projects', '550');
 JToolBarHelper::editList();
@@ -41,7 +32,8 @@ function submitbutton(pressbutton)
 		<label for="search">
 			<?php echo JText::_('Search'); ?>: 
 			<input type="text" name="search" id="search" value="<?php echo $this->filters['search']; ?>" />
-		</label>	
+		</label>
+	
 		<input type="submit" name="filter_submit" id="filter_submit" value="<?php echo JText::_('Go'); ?>" />
 	</fieldset>
 	<table class="adminlist" id="projects-admin">
@@ -53,6 +45,7 @@ function submitbutton(pressbutton)
 				<th><?php echo JHTML::_('grid.sort', 'Title', 'title', @$this->filters['sortdir'], @$this->filters['sortby'] ); ?></th>
 				<th colspan="2"><?php echo JHTML::_('grid.sort', 'Owner', 'owner', @$this->filters['sortdir'], @$this->filters['sortby'] ); ?></th>
 				<th><?php echo JHTML::_('grid.sort', 'Status', 'status', @$this->filters['sortdir'], @$this->filters['sortby'] ); ?></th>
+				<th><?php echo JHTML::_('grid.sort', 'Type', 'type', @$this->filters['sortdir'], @$this->filters['sortby'] ); ?></th>
 				<th><?php echo JHTML::_('grid.sort', 'Privacy', 'privacy', @$this->filters['sortdir'], @$this->filters['sortby'] ); ?></th>
 				<th><?php echo JText::_('Activity count'); ?></th>
 			</tr>
@@ -67,15 +60,12 @@ function submitbutton(pressbutton)
 			$k = 0;
 			$filterstring  = ($this->filters['sortby'])   ? '&amp;sort='.$this->filters['sortby']     : '';
 
-			$database = JFactory::getDBO();
-			$now = JFactory::getDate()->toSql();
-			
-			$database = JFactory::getDBO();
-			$pt = new ProjectTags($database);
+			$database =& JFactory::getDBO();
+			$now = date( "Y-m-d H:i:s" );
 			
 			for ($i=0, $n=count( $this->rows ); $i < $n; $i++) 
 			{
-				$row = $this->rows[$i];
+				$row =& $this->rows[$i];
 				
 				$thumb = ProjectsHtml::getThumbSrc($row->id, $row->alias, $row->picture, $this->config);
 				
@@ -88,7 +78,7 @@ function submitbutton(pressbutton)
 				// Determine status
 				$status = '';
 				if($row->state == 1 && $row->setup_stage >= $setup_complete) {
-					$status = '<span class="active">'.JText::_('Active').'</span> '.JText::_('since').' '.JHTML::_('date', $row->created, $dateFormat, $tz);
+					$status = '<span class="active">'.JText::_('Active').'</span> '.JText::_('since').' '.JHTML::_('date', $row->created, '%d %b. %Y');
 				}
 				else if($row->state == 2) {
 					$status  = '<span class="deleted">'.JText::_('Deleted').'</span> ';
@@ -102,8 +92,6 @@ function submitbutton(pressbutton)
 				else if($row->state == 5) {
 					$status = '<span class="inactive">'.JText::_('Pending approval').'</span> ';
 				}
-				
-				$tags = $pt->get_tag_cloud(3, 1, $row->id);
 	
 			?>
 						<tr class="<?php echo "row$k"; ?>">
@@ -112,15 +100,11 @@ function submitbutton(pressbutton)
 							<td style="width: 30px;"><?php echo '<img src="'.$thumb.'" width="30" height="30" alt="'.htmlentities($row->alias).'" />'; ?></td>
 							<td>
 								<a href="index.php?option=<?php echo $this->option ?>&amp;task=edit&amp;id[]=<?php echo $row->id;  echo $filterstring; ?>"><?php echo stripslashes($row->title); ?></a><br /><strong><?php echo stripslashes($row->alias); ?></strong>
-								<?php if ($tags) { ?>
-														<span class="project-tags block">
-															<?php echo $tags; ?>
-														</span>
-								<?php } ?>
 							</td>
 							<td style="width: 20px;"><?php echo $ownerclass; ?></td>
 							<td><?php echo $owner; ?></td>
-							<td><?php echo $status; ?></td>						
+							<td><?php echo $status; ?></td>
+							<td class="faded"><?php echo $row->projecttype; ?></td>							
 							<td><?php echo ($row->private == 1) ? '<span class="private">&nbsp;</span>' : ''; ?></td>
 							<td class="centeralign"><?php echo $row->activity; ?></td>
 						</tr>
@@ -137,4 +121,4 @@ function submitbutton(pressbutton)
 	<input type="hidden" name="filter_order" value="<?php echo $this->filters['sortby']; ?>" />
 	<input type="hidden" name="filter_order_Dir" value="<?php echo $this->filters['sortdir']; ?>" />
 	<?php echo JHTML::_( 'form.token' ); ?>
-</form>
+</form>
\ No newline at end of file
