@@ -34,147 +34,116 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Table class for a forum category
  */
-class ForumTableCategory extends JTable
+class ForumCategory extends JTable
 {
 	/**
 	 * int(11) Primary key
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $id         = NULL;
 
 	/**
 	 * varchar(255)
-	 *
-	 * @var string
+	 * 
+	 * @var unknown
 	 */
 	var $title      = NULL;
-
+	
 	/**
 	 * varchar(255)
-	 *
-	 * @var string
+	 * 
+	 * @var unknown
 	 */
 	var $alias      = NULL;
 
 	/**
 	 * text
-	 *
-	 * @var string
+	 * 
+	 * @var unknown
 	 */
 	var $description    = NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
-	 * @var string
+	 * 
+	 * @var unknown
 	 */
 	var $created    = NULL;
 
 	/**
 	 * int(11)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $created_by = NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
-	 * @var string
+	 * 
+	 * @var unknown
 	 */
 	var $modified   = NULL;
 
 	/**
 	 * int(11)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $modified_by = NULL;
 
 	/**
 	 * int(2)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $state      = NULL;
 
 	/**
 	 * int(11)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $hits       = NULL;
 
-	/**
-	 * varchar(100)
-	 *
-	 * @var string
-	 */
-	var $scope = NULL;
-
 	/**
 	 * int(11)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
-	var $scope_id = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	//var $scope_sub_id = NULL;
+	var $group_id = NULL;
 
 	/**
 	 * tinyint(2)  0=public, 1=registered, 2=special, 3=protected, 4=private
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $access     = NULL;
-
+	
 	/**
 	 * int(11)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $section_id = NULL;
-
+	
 	/**
 	 * tinyint(2)
-	 *
-	 * @var integer
+	 * 
+	 * @var unknown
 	 */
 	var $closed = null;
-
+	
 	/**
-	 * int(11)
 	 * ID for ACL asset (J1.6+)
-	 *
-	 * @var integer
+	 * 
+	 * @var int(11)
 	 */
 	var $asset_id = NULL;
 
-	/**
-	 * int(11)
-	 * Used to associate another object such as a
-	 * course lecture to a specific entry
-	 *
-	 * @var integer
-	 */
-	var $object_id = NULL;
-
-	/**
-	 * int(11)
-	 *
-	 * @var integer
-	 */
-	var $ordering = NULL;
-
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -224,269 +193,173 @@ class ForumTableCategory extends JTable
 	{
 		// Initialise variables.
 		$assetId = null;
-		$db = $this->getDbo();
+		$db		= $this->getDbo();
 
-		if ($assetId === null)
+		if ($assetId === null) 
 		{
 			// Build the query to get the asset id for the parent category.
-			$query = $db->getQuery(true);
+			$query	= $db->getQuery(true);
 			$query->select('id');
 			$query->from('#__assets');
 			$query->where('name = ' . $db->quote('com_forum'));
 
 			// Get the asset id from the database.
 			$db->setQuery($query);
-			if ($result = $db->loadResult())
+			if ($result = $db->loadResult()) 
 			{
 				$assetId = (int) $result;
 			}
 		}
 
 		// Return the asset id.
-		if ($assetId)
+		if ($assetId) 
 		{
 			return $assetId;
-		}
-		else
+		} 
+		else 
 		{
 			return parent::_getAssetParentId($table, $id);
 		}
 	}
 
-	/**
-	 * Overloaded bind function.
-	 *
-	 * @param   mixed  $src     An associative array or object to bind to the JTable instance.
-	 * @param   mixed  $ignore  An optional array or space separated list of properties to ignore.
-	 * @return  mixed  Null if operation was satisfactory, otherwise returns an error
-	 */
-	public function bind($src, $ignore = array())
-	{
-		// Bind the rules.
-		if (is_object($src))
-		{
-			if (isset($src->rules) && is_array($src->rules))
-			{
-				$rules = new \JAccessRules($src->rules);
-				$this->setRules($rules);
-			}
-		}
-		else if (is_array($src))
-		{
-			if (isset($src['rules']) && is_array($src['rules']))
-			{
-				$rules = new \JAccessRules($src['rules']);
-				$this->setRules($rules);
-			}
-		}
-
-		return parent::bind($src, $ignore);
-	}
-
 	/**
 	 * Load a record and bind to $this
-	 *
+	 * 
 	 * @param      string $oid Record alias
 	 * @return     boolean True on success
 	 */
-	public function loadByAlias($oid=NULL, $section_id=null, $scope_id=null, $scope='site')
+	public function loadByAlias($oid=NULL, $section_id=null, $group_id=null)
 	{
-		$fields = array(
-			'alias' => trim((string) $oid),
-			'state' => 1
-		);
-
+		if ($oid === NULL) 
+		{
+			return false;
+		}
+		$oid = trim($oid);
+		
+		$query = "SELECT * FROM $this->_tbl WHERE alias='$oid'";
 		if ($section_id !== null)
 		{
-			$fields['section_id'] = (int) $section_id;
+			$query .= " AND section_id=" . $section_id;
 		}
-		if ($scope_id !== null)
+		if ($group_id !== null)
 		{
-			$fields['scope_id'] = (int) $scope_id;
-			$fields['scope']    = (string) $scope;
+			$query .= " AND group_id=" . $group_id;
 		}
 
-		return parent::load($fields);
-	}
-
-	/**
-	 * Load a record by its alias and bind data to $this
-	 *
-	 * @param      string $oid Record alias
-	 * @return     boolean True upon success, False if errors
-	 */
-	public function loadByObject($oid=NULL, $section_id=null, $scope_id=null, $scope='site')
-	{
-		$fields = array(
-			'object_id' => intval($oid),
-			'state'     => 1
-		);
-
-		if ($section_id !== null)
+		$this->_db->setQuery($query);
+		if ($result = $this->_db->loadAssoc()) 
 		{
-			$fields['section_id'] = (int) $section_id;
-		}
-		if ($scope_id !== null)
+			return $this->bind($result);
+		} 
+		else 
 		{
-			$fields['scope_id'] = (int) $scope_id;
-			$fields['scope']    = (string) $scope;
+			$this->setError($this->_db->getErrorMsg());
+			return false;
 		}
-
-		return parent::load($fields);
 	}
 
 	/**
 	 * Populate the object with default data
-	 *
+	 * 
 	 * @param      integer $group ID of group the data belongs to
 	 * @return     boolean True if data is bound to $this object
 	 */
-	public function loadDefault($scope_id=0, $scope='site')
+	public function loadDefault($group=0)
 	{
 		$result = array(
-			'id'          => 0,
-			'title'       => JText::_('Discussions'),
+			'id' => 0,
+			'title' => JText::_('Discussions'),
 			'description' => JText::_('Default category for all discussions in this forum.'),
-			'section_id'  => 0,
-			'created_by'  => 0,
-			'scope'       => $scope,
-			'scope_id'    => $scope_id,
-			'state'       => 1,
-			'access'      => 1
+			'section_id' => 0,
+			'created_by' => 0,
+			'group_id' => $group,
+			'state' => 1,
+			'access' => 1
 		);
 		$result['alias'] = str_replace(' ', '-', $result['title']);
 		$result['alias'] = preg_replace("/[^a-zA-Z0-9\-]/", '', strtolower($result['alias']));
-
+		
 		return $this->bind($result);
 	}
 
 	/**
 	 * Validate data
-	 *
+	 * 
 	 * @return     boolean True if data is valid
 	 */
 	public function check()
 	{
 		$this->title = trim($this->title);
-
-		if (!$this->title)
+		
+		if (!$this->title) 
 		{
 			$this->setError(JText::_('Please provide a title.'));
 			return false;
 		}
-
+		
 		if (!$this->alias)
 		{
 			$this->alias = str_replace(' ', '-', strtolower($this->title));
 		}
 		$this->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', $this->alias);
-		if (!$this->alias)
-		{
-			$this->setError(JText::_('Alias cannot be all punctuation or blank.'));
-			return false;
-		}
-
-		$this->scope = preg_replace("/[^a-zA-Z0-9]/", '', strtolower($this->scope));
-		$this->scope_id = intval($this->scope_id);
-
-		$juser = JFactory::getUser();
+		
+		$juser =& JFactory::getUser();
 		if (!$this->id)
 		{
-			$this->created = JFactory::getDate()->toSql();
+			$this->created = date('Y-m-d H:i:s', time());
 			$this->created_by = $juser->get('id');
-			if (!$this->ordering)
-			{
-				$this->ordering = $this->getHighestOrdering($this->scope, $this->scope_id);
-			}
 		}
-		else
+		else 
 		{
-			$this->modified = JFactory::getDate()->toSql();
+			$this->modified = date('Y-m-d H:i:s', time());
 			$this->modified_by = $juser->get('id');
 		}
-
+		
 		return true;
 	}
 
-	/**
-	 * Get the last page in the ordering
-	 *
-	 * @param      string  $offering_id
-	 * @return     integer
-	 */
-	public function getHighestOrdering($scope, $scope_id)
-	{
-		$sql = "SELECT MAX(ordering)+1 FROM $this->_tbl WHERE scope_id=" . $this->_db->Quote(intval($scope_id)) . " AND scope=" . $this->_db->Quote($scope);
-		$this->_db->setQuery($sql);
-		return $this->_db->loadResult();
-	}
-
 	/**
 	 * Build a query based off of filters passed
-	 *
+	 * 
 	 * @param      array $filters Filters to construct query from
 	 * @return     string SQL
 	 */
 	protected function _buildQuery($filters=array())
 	{
 		$query  = "FROM $this->_tbl AS c";
-		if (isset($filters['group']) && (int) $filters['group'] >= 0)
+		$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.group_id";
+		if (version_compare(JVERSION, '1.6', 'lt'))
 		{
-			$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.scope_id";
+			$query .= " LEFT JOIN #__groups AS a ON c.access=a.id";
+		}
+		else 
+		{
+			$query .= " LEFT JOIN #__viewlevels AS a ON c.access=a.id";
 		}
-		$query .= " LEFT JOIN #__viewlevels AS a ON c.access=a.id";
 
 		$where = array();
-		if (isset($filters['state']) && (int) $filters['state'] >= 0)
+		if (isset($filters['state'])) 
 		{
-			$where[] = "c.state=" . $this->_db->Quote(intval($filters['state']));
+			$where[] = "c.state=" . $this->_db->Quote($filters['state']);
 		}
-		if (isset($filters['access']))
+		if (isset($filters['closed'])) 
 		{
-			if (is_array($filters['access']))
-			{
-				$filters['access'] = array_map('intval', $filters['access']);
-				$where[] = "c.access IN (" . implode(',', $filters['access']) . ")";
-			}
-			else if ($filters['access'] >= 0)
-			{
-				$where[] = "c.access=" . $this->_db->Quote(intval($filters['access']));
-			}
+			$where[] = "c.closed=" . $this->_db->Quote($filters['closed']);
 		}
-		if (isset($filters['closed']))
+		if (isset($filters['group']) && $filters['group'] >= 0) 
 		{
-			$where[] = "c.closed=" . $this->_db->Quote(intval($filters['closed']));
+			$where[] = "c.group_id=" . $this->_db->Quote($filters['group']);
 		}
-		if (isset($filters['group']) && (int) $filters['group'] >= 0)
+		if (isset($filters['section_id']) && $filters['section_id'] >= 0) 
 		{
-			$where[] = "(c.scope_id=" . $this->_db->Quote(intval($filters['group'])) . " AND c.scope=" . $this->_db->Quote('group') . ")";
+			$where[] = "c.section_id=" . $this->_db->Quote($filters['section_id']);
 		}
-		if (isset($filters['scope']) && (string) $filters['scope'])
+		if (isset($filters['search']) && $filters['search'] != '') 
 		{
-			$where[] = "c.scope=" . $this->_db->Quote(strtolower($filters['scope']));
+			$where[] = "(LOWER(c.title) LIKE '%" . strtolower($filters['search']) . "%' 
+				OR LOWER(c.description) LIKE '%" . strtolower($filters['search']) . "%')";
 		}
-		if (isset($filters['scope_id']) && (int) $filters['scope_id'] >= 0)
-		{
-			$where[] = "c.scope_id=" . $this->_db->Quote(intval($filters['scope_id']));
-		}
-		/*if (isset($filters['scope_sub_id']) && (int) $filters['scope_sub_id'] >= 0)
-		{
-			$where[] = "c.scope_sub_id=" . $this->_db->Quote(intval($filters['scope_sub_id']));
-		}*/
-		if (isset($filters['section_id']) && (int) $filters['section_id'] >= 0)
-		{
-			$where[] = "c.section_id=" . $this->_db->Quote(intval($filters['section_id']));
-		}
-		if (isset($filters['object_id']) && (int) $filters['object_id'] >= 0)
-		{
-			$where[] = "c.object_id=" . $this->_db->Quote(intval($filters['object_id']));
-		}
-		if (isset($filters['search']) && $filters['search'] != '')
-		{
-			$where[] = "(LOWER(c.title) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . "
-				OR LOWER(c.description) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . ")";
-		}
-
+		
 		if (count($where) > 0)
 		{
 			$query .= " WHERE ";
@@ -498,7 +371,7 @@ class ForumTableCategory extends JTable
 
 	/**
 	 * Get a record count
-	 *
+	 * 
 	 * @param      array $filters Filters to construct query from
 	 * @return     integer
 	 */
@@ -514,64 +387,45 @@ class ForumTableCategory extends JTable
 
 	/**
 	 * Get records
-	 *
+	 * 
 	 * @param      array $filters Filters to construct query from
 	 * @return     array
 	 */
 	public function getRecords($filters=array())
 	{
-		$flt = "";
-		if (isset($filters['scope_sub_id']) && (int) $filters['scope_sub_id'] >= 0)
-		{
-			$flt = " AND (r.scope_sub_id=" . $this->_db->Quote(intval($filters['scope_sub_id'])) . " OR r.sticky=1)";
-		}
-		if (isset($filters['access']))
-		{
-			if (is_array($filters['access']))
-			{
-				$filters['access'] = array_map('intval', $filters['access']);
-				$flt .= " AND r.access IN (" . implode(',', $filters['access']) . ")";
-			}
-			else if ($filters['access'] >= 0)
-			{
-				$flt .= " AND r.access=" . $this->_db->Quote(intval($filters['access']));
-			}
-		}
-
 		if (isset($filters['admin']))
 		{
-			$query  = "SELECT c.*";
-			if (isset($filters['group']) && (int) $filters['group'] >= 0)
-			{
-				$query .= ", g.cn AS group_alias";
-			}
-			$query .= ", (SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0 $flt) AS threads,
-						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id $flt) AS posts";
+			$query  = "SELECT c.*, g.cn AS group_alias, 
+						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0) AS threads,
+						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id) AS posts";
 		}
-		else
+		else 
 		{
-			$query  = "SELECT c.*";
-			if (isset($filters['group']) && (int) $filters['group'] >= 0)
-			{
-				$query .= ", g.cn AS group_alias";
-			}
-			$query .= ", (SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0 AND r.state=1 $flt) AS threads,
-						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.state=1 $flt) AS posts";
+			$query  = "SELECT c.*, g.cn AS group_alias, 
+						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0 AND r.state=1) AS threads,
+						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.state=1) AS posts";
+		}
+		if (version_compare(JVERSION, '1.6', 'lt'))
+		{
+			$query .= ", a.name AS access_level";
+		}
+		else 
+		{
+			$query .= ", a.title AS access_level";
 		}
-		$query .= ", a.title AS access_level";
 		$query .= " " . $this->_buildQuery($filters);
 
-		if (!isset($filters['sort']) || !$filters['sort'])
+		if (!isset($filters['sort']) || !$filters['sort']) 
 		{
 			$filters['sort'] = 'title';
 		}
-		if (!isset($filters['sort_Dir']) || !$filters['sort_Dir'])
+		if (!isset($filters['sort_Dir']) || !$filters['sort_Dir']) 
 		{
 			$filters['sort_Dir'] = 'ASC';
 		}
 		$query .= " ORDER BY " . $filters['sort'] . " " . $filters['sort_Dir'];
 
-		if (isset($filters['limit']) && $filters['limit'] != 0)
+		if (isset($filters['limit']) && $filters['limit'] != 0) 
 		{
 			$query .= ' LIMIT ' . $filters['start'] . ',' . $filters['limit'];
 		}
@@ -582,20 +436,20 @@ class ForumTableCategory extends JTable
 
 	/**
 	 * Get a count of all threads for a category
-	 *
+	 * 
 	 * @param      integer $oid      Category ID
 	 * @param      integer $group_id Group ID
 	 * @return     array
 	 */
-	public function getThreadCount($oid=null, $scope_id=0, $scope='site')
+	public function getThreadCount($oid=null, $group_id=0)
 	{
 		$k = $this->_tbl_key;
-		if ($oid !== null)
+		if ($oid !== null) 
 		{
 			$this->$k = intval($oid);
 		}
 
-		$query = "SELECT COUNT(*) FROM #__forum_posts WHERE category_id=" . $this->_db->Quote($this->$k) . " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope) . " AND parent=0 AND state < 2";
+		$query = "SELECT COUNT(*) FROM #__forum_posts WHERE category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2";
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
@@ -603,84 +457,84 @@ class ForumTableCategory extends JTable
 
 	/**
 	 * Get a count of all posts for a category
-	 *
+	 * 
 	 * @param      integer $oid      Category ID
 	 * @param      integer $group_id Group ID
 	 * @return     array
 	 */
-	public function getPostCount($oid=null, $scope_id=0, $scope='site')
+	public function getPostCount($oid=null, $group_id=0)
 	{
 		$k = $this->_tbl_key;
-		if ($oid !== null)
+		if ($oid !== null) 
 		{
 			$this->$k = intval($oid);
 		}
 
 		//$query = "SELECT COUNT(*) FROM #__forum_posts WHERE parent IN (SELECT r.id FROM #__forum_posts AS r WHERE r.category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2)";
-		$query = "SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=" . $this->_db->Quote($this->$k) . " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope) . " AND parent=0 AND state < 2";
+		$query = "SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2";
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
 	}
 
 	/**
 	 * Delete a category and all associated content
-	 *
+	 * 
 	 * @param      integer $oid Object ID (primary key)
 	 * @return     true if successful otherwise returns and error message
 	 */
 	public function delete($oid=null)
 	{
 		$k = $this->_tbl_key;
-		if ($oid)
+		if ($oid) 
 		{
 			$this->$k = intval($oid);
 		}
-
-		$post = new ForumTablePost($this->_db);
+		
+		$post = new ForumPost($this->_db);
 		if (!$post->deleteByCategory($this->$k))
 		{
 			$this->setError($post->getErrorMsg());
 			return false;
 		}
-
+		
 		return parent::delete();
 	}
 
 	/**
 	 * Set the state of records for a section
-	 *
+	 * 
 	 * @param      integer $section Section ID
 	 * @param      integer $state   State (0, 1, 2)
 	 * @return     array
 	 */
 	public function setStateBySection($section=null, $state=null)
 	{
-		if ($section=== null)
+		if ($section=== null) 
 		{
 			$section = $this->section_id;
 		}
-		if ($state === null || $section === null)
+		if ($state === null || $section === null) 
 		{
 			return false;
 		}
-
+		
 		if (is_array($section))
 		{
 			$section = array_map('intval', $section);
 			$section = implode(',', $section);
 		}
-		else
+		else 
 		{
 			$section = intval($section);
 		}
-
-		$this->_db->setQuery("UPDATE $this->_tbl SET state=" . $this->_db->Quote($state) . " WHERE section_id IN ($section)");
-		if (!$this->_db->query())
+		
+		$this->_db->setQuery("UPDATE $this->_tbl SET state=$state WHERE section_id IN ($section)");
+		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
-		}
-		else
+		} 
+		else 
 		{
 			return true;
 		}
