@@ -31,24 +31,24 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Members controller class for media
  */
-class MembersControllerMedia extends \Hubzero\Component\SiteController
+class MembersControllerMedia extends Hubzero_Controller
 {
 	/**
 	 * Execute a task
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
 	{
-		$parts = explode('/', $_SERVER['REQUEST_URI']);
+		$file = array_pop(explode('/', $_SERVER['REQUEST_URI']));
 
-		$file = array_pop($parts);
-
-		if (substr(strtolower($file), 0, 5) == 'image'
-		 || substr(strtolower($file), 0, 4) == 'file')
+		if (substr(strtolower($file), 0, 5) == 'image' 
+		 || substr(strtolower($file), 0, 4) == 'file') 
 		{
 			JRequest::setVar('task', 'download');
 		}
@@ -60,7 +60,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for uploading a file
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function ajaxuploadTask()
@@ -73,17 +73,12 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		//load profile from id
-		$this->view->profile = \Hubzero\User\Profile::getInstance($id);
-
-		if (!$this->view->profile)
-		{
-			JError::raiseError(404, JText::_('MEMBERS_NO_ID'));
-		}
+		$this->view->profile = Hubzero_User_Profile::getInstance($id);
 
 		//instantiate view and pass needed vars
 		$this->view->setLayout('upload');
 		$this->view->config = $this->config;
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -95,14 +90,11 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the profile via AJAX
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function doajaxuploadTask()
 	{
-		// Check for request forgeries
-		//JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
-
 		//allowed extensions for uplaod
 		$allowedExtensions = array('png', 'jpe', 'jpeg', 'jpg', 'gif');
 
@@ -129,14 +121,14 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 		//get the id and load profile
 		$id = JRequest::getVar('id', 0);
-		$profile = \Hubzero\User\Profile::getInstance($id);
+		$profile = Hubzero_User_Profile::getInstance($id);
 		if (!$profile)
 		{
 			return;
 		}
 
 		//define upload directory and make sure its writable
-		$uploadDirectory = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/members'), DS) . DS . \Hubzero\Utility\String::pad($id) . DS;
+		$uploadDirectory = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/members'), DS) . DS . Hubzero_View_Helper_Html::niceidformat($id) . DS;
 
 		if (!is_dir($uploadDirectory))
 		{
@@ -154,14 +146,14 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		//check to make sure we have a file and its not too big
-		if ($size == 0)
+		if ($size == 0) 
 		{
 			echo json_encode(array('error' => 'File is empty'));
 			return;
 		}
-		if ($size > $sizeLimit)
+		if ($size > $sizeLimit) 
 		{
-			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', \Hubzero\Utility\Number::formatBytes($sizeLimit));
+			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', Hubzero_View_Helper_Html::formatSize($sizeLimit));
 			echo json_encode(array('error' => 'File is too large. Max file upload size is ' . $max));
 			return;
 		}
@@ -178,14 +170,14 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// don't overwrite previous files that were uploaded
-		while (file_exists($uploadDirectory . $filename . '.' . $ext))
+		while (file_exists($uploadDirectory . $filename . '.' . $ext)) 
 		{
 			$filename .= rand(10, 99);
 		}
 
 		$file = $uploadDirectory . $filename . '.' . $ext;
 		$final_file = $uploadDirectory . 'profile.png';
-		$final_thumb = $uploadDirectory . 'thumb.png';
+		$final_thumb = $uploadDirectory . 'thumb.png'; 
 
 		if ($stream)
 		{
@@ -205,9 +197,10 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		{
 			move_uploaded_file($_FILES['qqfile']['tmp_name'], $file);
 		}
-
+		
 		//resize image to max 400px and rotate in case user didnt before uploading
-		$hi = new \Hubzero\Image\Processor($file);
+		ximport('Hubzero_Image');
+		$hi = new Hubzero_Image($file);
 		if (count($hi->getErrors()) == 0)
 		{
 			$hi->autoRotate();
@@ -217,12 +210,12 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 		else
 		{
-			echo json_encode(array('error' => $hi->getError()));
+			echo json_encode(array('error' => $hi->getErrors()));
 			return;
 		}
 
 		// create thumb
-		$hi = new \Hubzero\Image\Processor($final_file);
+		$hi = new Hubzero_Image($final_file);
 		if (count($hi->getErrors()) == 0)
 		{
 			$hi->resize(50, false, true, true);
@@ -230,7 +223,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 		else
 		{
-			echo json_encode(array('error' => $hi->getError()));
+			echo json_encode(array('error' => $hi->getErrors()));
 			return;
 		}
 
@@ -238,23 +231,20 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		unlink($file);
 
 		echo json_encode(array(
-			'success'   => true,
-			'file'      => str_replace($uploadDirectory, '', $final_file),
+			'success'   => true, 
+			'file'      => str_replace($uploadDirectory, '', $final_file), 
 			'directory' => str_replace(JPATH_ROOT, '', $uploadDirectory)
 		));
 	}
 
 	/**
 	 * Set the picture of a profile
-	 *
+	 * 
 	 * @return     string JSON
 	 */
 	public function ajaxuploadsaveTask()
 	{
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
-		//get the user id
+		//get the user id 
 		$id = JRequest::getInt('id', 0);
 		if (!$id)
 		{
@@ -262,7 +252,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		//load the user profile
-		$profile = \Hubzero\User\Profile::getInstance($id);
+		$profile = Hubzero_User_Profile::getInstance($id);
 		if (!$profile)
 		{
 			echo json_encode(array('error' => 'Unable to locate user profile.'));
@@ -285,7 +275,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Get the size, width, height, and src attributes for a file
-	 *
+	 * 
 	 * @return     string JSON
 	 */
 	public function getfileattsTask()
@@ -299,12 +289,12 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		$size = filesize(JPATH_ROOT . $dir . $file);
-		list($width, $height) = getimagesize(JPATH_ROOT . $dir . $file);
+		list($width, $height) = getimagesize(JPATH_ROOT . $dir . $file); 
 
 		$result = array();
 		$result['src']    = $dir . $file;
 		$result['name']   = $file;
-		$result['size']   = \Hubzero\Utility\Number::formatBytes($size);
+		$result['size']   = Hubzero_View_Helper_Html::formatsize($size);
 		$result['width']  = $width . ' <abbr title="pixels">px</abbr>';
 		$result['height'] = $height . ' <abbr title="pixels">px</abbr>';
 
@@ -313,23 +303,20 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function uploadTask()
 	{
 		// Check if they are logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return false;
 		}
 
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		// Incoming member ID
 		$id = JRequest::getInt('id', 0);
-		if (!$id)
+		if (!$id) 
 		{
 			$this->setError(JText::_('MEMBERS_NO_ID'));
 			$this->displayTask('', $id);
@@ -338,7 +325,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 		// Incoming file
 		$file = JRequest::getVar('upload', '', 'files', 'array');
-		if (!$file['name'])
+		if (!$file['name']) 
 		{
 			$this->setError(JText::_('MEMBERS_NO_FILE'));
 			$this->displayTask('', $id);
@@ -346,13 +333,13 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// Build upload path
-		$dir  = \Hubzero\Utility\String::pad($id);
+		$dir  = Hubzero_View_Helper_Html::niceidformat($id);
 		$path = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/members'), DS) . DS . $dir;
 
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
 				$this->setError(JText::_('UNABLE_TO_CREATE_UPLOAD_PATH'));
 				$this->displayTask('', $id);
@@ -369,32 +356,32 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		$curfile = JRequest::getVar('currentfile', '');
 
 		// Perform the upload
-		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name']))
+		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name'])) 
 		{
 			$this->setError(JText::_('ERROR_UPLOADING'));
 			$file = $curfile;
-		}
-		else
+		} 
+		else 
 		{
 			$ih = new MembersImgHandler();
 
-			if ($curfile != '')
+			if ($curfile != '') 
 			{
 				// Yes - remove it
-				if (file_exists($path . DS . $curfile))
+				if (file_exists($path . DS . $curfile)) 
 				{
-					if (!JFile::delete($path . DS . $curfile))
+					if (!JFile::delete($path . DS . $curfile)) 
 					{
 						$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
 						$this->displayTask($file['name'], $id);
 						return;
 					}
 				}
-
+				
 				$curthumb = $ih->createThumbName($curfile);
-				if (file_exists($path . DS . $curthumb))
+				if (file_exists($path . DS . $curthumb)) 
 				{
-					if (!JFile::delete($path . DS . $curthumb))
+					if (!JFile::delete($path . DS . $curthumb)) 
 					{
 						$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
 						$this->displayTask($file['name'], $id);
@@ -404,9 +391,9 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 			}
 
 			// Instantiate a profile, change some info and save
-			$profile = \Hubzero\User\Profile::getInstance($id);
+			$profile = Hubzero_User_Profile::getInstance($id);
 			$profile->set('picture', $file['name']);
-			if (!$profile->update())
+			if (!$profile->update()) 
 			{
 				$this->setError($profile->getError());
 			}
@@ -416,7 +403,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 			$ih->set('path', $path . DS);
 			$ih->set('maxWidth', 186);
 			$ih->set('maxHeight', 186);
-			if (!$ih->process())
+			if (!$ih->process()) 
 			{
 				$this->setError($ih->getError());
 			}
@@ -426,7 +413,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 			$ih->set('maxHeight', 50);
 			$ih->set('cropratio', '1:1');
 			$ih->set('outputName', $ih->createThumbName());
-			if (!$ih->process())
+			if (!$ih->process()) 
 			{
 				$this->setError($ih->getError());
 			}
@@ -440,20 +427,20 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a file in the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deleteTask()
 	{
 		// Check if they are logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return false;
 		}
 
 		// Incoming member ID
 		$id = JRequest::getInt('id', 0);
-		if (!$id)
+		if (!$id) 
 		{
 			$this->setError(JText::_('MEMBERS_NO_ID'));
 			$this->displayTask('', $id);
@@ -461,27 +448,27 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 		// Incoming file
 		$file = JRequest::getVar('file', '');
-		if (!$file)
+		if (!$file) 
 		{
 			$this->setError(JText::_('MEMBERS_NO_FILE'));
 			$this->displayTask('', $id);
 		}
 
 		// Build the file path
-		$dir  = \Hubzero\Utility\String::pad($id);
+		$dir  = Hubzero_View_Helper_Html::niceidformat($id);
 		$path = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/members'), DS) . DS . $dir;
 
-		if (!file_exists($path . DS . $file) or !$file)
+		if (!file_exists($path . DS . $file) or !$file) 
 		{
 			$this->setError(JText::_('FILE_NOT_FOUND'));
-		}
-		else
+		} 
+		else 
 		{
 			$ih = new MembersImgHandler();
 
 			// Attempt to delete the file
 			jimport('joomla.filesystem.file');
-			if (!JFile::delete($path . DS . $file))
+			if (!JFile::delete($path . DS . $file)) 
 			{
 				$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
 				$this->displayTask($file, $id);
@@ -489,9 +476,9 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 			}
 
 			$curthumb = $ih->createThumbName($file);
-			if (file_exists($path . DS . $curthumb))
+			if (file_exists($path . DS . $curthumb)) 
 			{
-				if (!JFile::delete($path . DS . $curthumb))
+				if (!JFile::delete($path . DS . $curthumb)) 
 				{
 					$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
 					$this->displayTask($file, $id);
@@ -500,9 +487,9 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 			}
 
 			// Instantiate a profile, change some info and save
-			$profile = \Hubzero\User\Profile::getInstance($id);
+			$profile = Hubzero_User_Profile::getInstance($id);
 			$profile->set('picture', '');
-			if (!$profile->update())
+			if (!$profile->update()) 
 			{
 				$this->setError($profile->getError());
 			}
@@ -511,12 +498,12 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// Push through to the image view
-		$this->displayTask($file, $id);
+		$this->img($file, $id);
 	}
 
 	/**
 	 * Display a user's profile picture
-	 *
+	 * 
 	 * @param      string  $file File name
 	 * @param      integer $id   User ID
 	 * @return     void
@@ -524,20 +511,20 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 	public function displayTask($file='', $id=0)
 	{
 		// Incoming
-		if (!$id)
+		if (!$id) 
 		{
 			$id = JRequest::getInt('id', 0, 'get');
 		}
 		$this->view->id = $id;
 
-		if (!$file)
+		if (!$file) 
 		{
 			$file = JRequest::getVar('file', '', 'get');
 		}
 		$this->view->file = $file;
 
 		// Build the file path
-		$dir  = \Hubzero\Utility\String::pad($id);
+		$dir  = Hubzero_View_Helper_Html::niceidformat($id);
 		$path = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/members'), DS) . DS . $dir;
 
 		// Output HTML
@@ -547,14 +534,13 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 		$this->view->file_path = $path;
 
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
 				$this->view->setError($error);
 			}
 		}
-		$this->view->setLayout('display');
 		$this->view->display();
 	}
 
@@ -569,19 +555,29 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 	protected function _authorize($assetType='component', $assetId=null)
 	{
 		// Check if they are logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return false;
 		}
 
 		// Check if they're a site admin (from Joomla)
-		// Admin
-		$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-		$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-
-		if ($this->config->get('access-admin-' . $assetType))
+		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
-			return 'admin';
+			// Admin
+			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+
+			if ($this->config->get('access-admin-' . $assetType))
+			{
+				return 'admin';
+			}
+		}
+		else 
+		{
+			if ($this->juser->authorize($this->_option, 'manage'))
+			{
+				return 'admin';
+			}
 		}
 
 		return false;
@@ -589,7 +585,7 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Download a file
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function downloadTask()
@@ -598,84 +594,121 @@ class MembersControllerMedia extends \Hubzero\Component\SiteController
 		$id = JRequest::getInt('id', 0);
 
 		//check to make sure we have an id
-		if (!$id || $id == 0)
+		if (!$id || $id == 0) 
 		{
 			return;
 		}
 
 		//Load member profile
-		$member = \Hubzero\User\Profile::getInstance($id);
+		$member = Hubzero_User_Profile::getInstance($id);
 
 		// check to make sure we have member profile
-		if (!$member)
+		if (!$member) 
 		{
 			return;
 		}
 
+		$filename = array_pop(explode('/', $_SERVER['REQUEST_URI']));
+
 		//get the file name
-		// make sure to leave out any query params (ex. ?v={timestamp})
-		$uri = JRequest::getVar('SCRIPT_URL', '', 'server');
-		if (strstr($uri, 'Image:'))
+		if (substr(strtolower($filename), 0, 5) == 'image') 
 		{
-			$file = str_replace('Image:', '', strstr($uri, 'Image:'));
-		}
-		elseif (strstr($uri, 'File:'))
+			$file = substr($filename, 6);
+		} 
+		elseif (substr(strtolower($filename), 0, 4) == 'file') 
 		{
-			$file = str_replace('File:', '', strstr($uri, 'File:'));
+			$file = substr($filename, 5);
 		}
 
 		//decode file name
 		$file = urldecode($file);
 
-		// build base path
-		$base_path = trim($this->config->get('webpath', '/site/members'), DS);
-		$base_path .= DS . \Hubzero\User\Profile\Helper::niceidformat($member->get('uidNumber'));
-
 		//if we are on the blog
-		if (JRequest::getVar('active', 'profile') == 'blog')
+		if (JRequest::getVar('active', 'profile') == 'blog') 
 		{
 			// @FIXME Check still needs to occur for non-public entries
 			//authorize checks
-			/*if ($this->_authorize() != 'admin')
+			/*if ($this->_authorize() != 'admin') 
 			{
-				if ($this->juser->get('id') != $member->get('uidNumber'))
+				if ($this->juser->get('id') != $member->get('uidNumber')) 
 				{
 					JError::raiseError(403, JText::_('You are not authorized to download the file: ') . ' ' . $file);
 					return;
 				}
 			}*/
+			
+			$paramsClass = 'JParameter';
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$paramsClass = 'JRegistry';
+			}
 
 			//get the params from the members blog plugin
 			$blog_config = JPluginHelper::getPlugin('members', 'blog');
-			$blog_params = new JRegistry($blog_config->params);
+			$blog_params = new $paramsClass($blog_config->params);
+
+			ximport("Hubzero_User_Profile_Helper");
 
 			//build the base path to file based of upload path param
-			$base_path = str_replace('{{uid}}', \Hubzero\User\Profile\Helper::niceidformat($member->get('uidNumber')), $blog_params->get('uploadpath'));
+			$base_path = str_replace('{{uid}}', Hubzero_User_Profile_Helper::niceidformat($member->get('uidNumber')), $blog_params->get('uploadpath'));
 		}
 
 		//build file path
 		$file_path = $base_path . DS . $file;
 
 		// Ensure the file exist
-		if (!file_exists(JPATH_ROOT . DS . $file_path))
+		if (!file_exists(JPATH_ROOT . DS . $file_path)) 
 		{
 			JError::raiseError(404, JText::_('The requested file could not be found: ') . ' ' . $file);
 			return;
 		}
 
+		if (preg_match("/^\s*http[s]{0,1}:/i", $file_path)) 
+		{
+			JError::raiseError(404, JText::_('COM_MEMBERS_BAD_FILE_PATH'));
+			return;
+		}
+		if (preg_match("/^\s*[\/]{0,1}index.php\?/i", $file_path)) 
+		{
+			JError::raiseError(404, JText::_('COM_MEMBERS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow windows drive letter
+		if (preg_match("/^\s*[.]:/", $file_path)) 
+		{
+			JError::raiseError(404, JText::_('COM_MEMBERS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow \
+		if (strpos('\\', $file_path)) 
+		{
+			JError::raiseError(404, JText::_('COM_MEMBERS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow ..
+		if (strpos('..', $file_path)) 
+		{
+			JError::raiseError(404, JText::_('COM_MEMBERS_BAD_FILE_PATH'));
+			return;
+		}
+
+		// Get some needed libraries
+		ximport('Hubzero_Content_Server');
+
+
 		// Serve up the image
-		$xserver = new \Hubzero\Content\Server();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename(JPATH_ROOT . DS . $file_path);
 		$xserver->disposition('attachment');
 		$xserver->acceptranges(false); // @TODO fix byte range support
 
 		//serve up file
-		if (!$xserver->serve())
+		if (!$xserver->serve()) 
 		{
 			// Should only get here on error
 			JError::raiseError(404, JText::_('An error occured while trying to output the file'));
-		}
-		else
+		} 
+		else 
 		{
 			exit;
 		}
