@@ -34,53 +34,55 @@ defined('_JEXEC') or die('Restricted access');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'tag.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'object.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'substitute.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'tables' . DS . 'group.php');
 
 /**
  * Tag helper class for adding/removing/displaying tags on objects
  *
- * Generally, direct use is rare (and discouraged). It will
- * typically be extended by another component.
+ * Generally, direct use is rare (and discouraged). It will 
+ * typically be extended by another component, such as 
+ * ResourcesTags or AnswersTags.
  */
 class TagsHandler extends JObject
 {
 	/**
 	 * Database
-	 *
+	 * 
 	 * @var unknown
 	 */
 	public $_db  = NULL;
 
 	/**
 	 * Object type, used for linking objects (such as resources) to tags
-	 *
+	 * 
 	 * @var string
 	 */
 	public $_tbl = 'tags';
 
 	/**
 	 * The object to be tagged
-	 *
+	 * 
 	 * @var unknown
 	 */
-	public $_oid = NULL;  //
+	public $_oid = NULL;  // 
 
 	/**
 	 * The primary tag table
-	 *
+	 * 
 	 * @var string
 	 */
 	public $_tag_tbl = '#__tags';
 
 	/**
 	 * Tag/object mapping table
-	 *
+	 * 
 	 * @var string
 	 */
 	public $_obj_tbl = '#__tags_object';
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object $db     JDatabase
 	 * @param      array  $config Configuration options
 	 * @return     void
@@ -92,32 +94,31 @@ class TagsHandler extends JObject
 
 	/**
 	 * Get all the tags on an object
-	 *
+	 * 
 	 * @param      integer $object_id Object ID
 	 * @param      integer $offset    Record offset
 	 * @param      integer $limit     Record limit
 	 * @param      integer $tagger_id Tagger ID (set this if you want to restrict tags only added by a specific user)
 	 * @param      integer $strength  Tag strength (set this if you want to restrict tags by strength)
 	 * @param      integer $admin     Has admin access?
-	 * @return     array
+	 * @return     array 
 	 */
-	public function get_tags_on_object($object_id, $offset=0, $limit=10, $tagger_id=NULL, $strength=0, $admin=0, $label='')
+	public function get_tags_on_object($object_id, $offset=0, $limit=10, $tagger_id=NULL, $strength=0, $admin=0)
 	{
-		if (!isset($object_id))
+		if (!isset($object_id)) 
 		{
 			$this->setError('get_tags_on_object argument missing');
 			return array();
 		}
 
-		$to = new TagsTableObject($this->_db);
+		$to = new TagsObject($this->_db);
 		$to->objectid = $object_id;
 		$to->tbl = $this->_tbl;
 		$to->strength = $strength;
 		$to->taggerid = $tagger_id;
-		$to->label = $label;
 
 		$tags = $to->getTagsOnObject($object_id, $this->_tbl, $admin, $offset, $limit);
-		if (!$tags)
+		if (!$tags) 
 		{
 			$this->setError($to->getError());
 			return array();
@@ -131,63 +132,56 @@ class TagsHandler extends JObject
 	 * 1) First, check if the tag already exists
 	 *    a) if not, creates a database entry for the tag
 	 * 2) Adds a reference linking tag with object
-	 *
+	 * 
 	 * @param      integer $tagger_id Tagger ID
 	 * @param      integer $object_id Object ID
 	 * @param      string  $tag       Tag
 	 * @param      integer $strength  Tag strength
 	 * @return     boolean True on success, false if errors
 	 */
-	public function safe_tag($tagger_id, $object_id, $tag, $strength=1, $label='')
+	public function safe_tag($tagger_id, $object_id, $tag, $strength=1)
 	{
-		if (!isset($tagger_id) || !isset($object_id) || !isset($tag))
+		if (!isset($tagger_id) || !isset($object_id) || !isset($tag)) 
 		{
 			$this->setError('safe_tag argument missing');
 			return false;
 		}
 
-		if ($this->normalize_tag($tag) === '0')
+		if ($this->normalize_tag($tag) === '0') 
 		{
 			return true;
 		}
 
-		$to = new TagsTableObject($this->_db);
+		$to = new TagsObject($this->_db);
 		$to->objectid = $object_id;
 		$to->tbl = $this->_tbl;
-		$to->label = $label;
 
 		// First see if the tag exists.
-		$t = new TagsTableTag($this->_db);
-		$t->loadTag($t->normalize($tag));
-		if (!$t->id)
+		$t = new TagsTag($this->_db);
+		$t->loadTag($this->normalize_tag($tag));
+		if (!$t->id) 
 		{
-			// Add new tag!
-			$t->tag = $t->normalize($tag);
+			// Add new tag! 
+			$t->tag = $this->normalize_tag($tag);
 			$t->raw_tag = addslashes($tag);
-			$t->created = \JFactory::getDate()->toSql();
-			$t->created_by = $tagger_id;
-			if (!$t->check())
+
+			if (!$t->store()) 
 			{
 				$this->setError($t->getError());
 				return false;
 			}
-			if (!$t->store())
-			{
-				$this->setError($t->getError());
-				return false;
-			}
-			if (!$t->id)
+			if (!$t->id) 
 			{
 				return false;
 			}
 			$to->tagid = $t->id;
-		}
-		else
+		} 
+		else 
 		{
 			$to->tagid = $t->id;
 
 			// Check if the object has already been tagged
-			if ($to->getCountForObject() > 0)
+			if ($to->getCountForObject() > 0) 
 			{
 				return true;
 			}
@@ -196,9 +190,9 @@ class TagsHandler extends JObject
 		// Add an entry linking the tag to the object it was used on
 		$to->strength = $strength;
 		$to->taggerid = $tagger_id;
-		$to->taggedon = JFactory::getDate()->toSql();
+		$to->taggedon = date('Y-m-d H:i:s', time());
 
-		if (!$to->store())
+		if (!$to->store()) 
 		{
 			$this->setError($to->getError());
 			return false;
@@ -209,10 +203,10 @@ class TagsHandler extends JObject
 
 	/**
 	 * Tag an object
-	 * This will get a list of old tags on object and will
-	 * 1) add any new tags not in the old list
+	 * This will get a list of old tags on object and will 
+	 * 1) add any new tags not in the old list 
 	 * 2) remove any tags in the old list not found in the new list
-	 *
+	 * 
 	 * @param      integer $tagger_id  Tagger ID
 	 * @param      integer $object_id  Object ID
 	 * @param      string  $tag_string String of comma-separated tags
@@ -220,31 +214,31 @@ class TagsHandler extends JObject
 	 * @param      boolean $admin      Has admin access?
 	 * @return     boolean True on success, false if errors
 	 */
-	public function tag_object($tagger_id, $object_id, $tag_string, $strength, $admin=false, $label='')
+	public function tag_object($tagger_id, $object_id, $tag_string, $strength, $admin=false)
 	{
 		$tagArray  = $this->_parse_tags($tag_string);   // array of normalized tags
 		$tagArray2 = $this->_parse_tags($tag_string, 1); // array of normalized => raw tags
-		if ($admin)
+		if ($admin) 
 		{
-			$oldTags = $this->get_tags_on_object($object_id, 0, 0, 0, 0, 1, $label); // tags currently assigned to an object
-		}
-		else
+			$oldTags = $this->get_tags_on_object($object_id, 0, 0, 0, 0, 1); // tags currently assigned to an object
+		} 
+		else 
 		{
-			$oldTags = $this->get_tags_on_object($object_id, 0, 0, $tagger_id, 0, 0, $label); // tags currently assigned to an object
+			$oldTags = $this->get_tags_on_object($object_id, 0, 0, $tagger_id, 0, 0); // tags currently assigned to an object
 		}
 
 		$preserveTags = array();
 
-		if (count($oldTags) > 0)
+		if (count($oldTags) > 0) 
 		{
 			foreach ($oldTags as $tagItem)
 			{
-				if (!in_array($tagItem['tag'], $tagArray))
+				if (!in_array($tagItem['tag'], $tagArray)) 
 				{
 					// We need to delete old tags that don't appear in the new parsed string.
 					$this->remove_tag($tagger_id, $object_id, $tagItem['tag'], $admin);
-				}
-				else
+				} 
+				else 
 				{
 					// We need to preserve old tags that appear (to save timestamps)
 					$preserveTags[] = $tagItem['tag'];
@@ -256,14 +250,14 @@ class TagsHandler extends JObject
 		foreach ($newTags as $tag)
 		{
 			$tag = trim($tag);
-			if ($tag != '')
+			if ($tag != '') 
 			{
-				if (get_magic_quotes_gpc())
+				if (get_magic_quotes_gpc()) 
 				{
 					$tag = addslashes($tag);
 				}
 				$thistag = $tagArray2[$tag];
-				$this->safe_tag($tagger_id, $object_id, $thistag, $strength, $label);
+				$this->safe_tag($tagger_id, $object_id, $thistag, $strength);
 			}
 		}
 		return true;
@@ -271,7 +265,7 @@ class TagsHandler extends JObject
 
 	/**
 	 * Remove a tag on an object
-	 *
+	 * 
 	 * @param      integer $tagger_id Tagger ID
 	 * @param      integer $object_id Object ID
 	 * @param      string  $tag       Tag to remove
@@ -280,20 +274,20 @@ class TagsHandler extends JObject
 	 */
 	public function remove_tag($tagger_id, $object_id, $tag, $admin)
 	{
-		if (!isset($object_id) || !isset($tag))
+		if (!isset($object_id) || !isset($tag)) 
 		{
 			$this->setError('remove_tag argument missing');
 			return false;
 		}
 
 		$tag_id = $this->get_tag_id($tag);
-		if (!$tag_id)
+		if (!$tag_id) 
 		{
 			return false;
 		}
 
-		$to = new TagsTableObject($this->_db);
-		if (!$to->deleteObjects($tag_id, $this->_tbl, $object_id, $tagger_id, $admin))
+		$to = new TagsObject($this->_db);
+		if (!$to->deleteObjects($tag_id, $this->_tbl, $object_id, $tagger_id, $admin)) 
 		{
 			$this->setError($to->getError());
 			return false;
@@ -303,23 +297,23 @@ class TagsHandler extends JObject
 
 	/**
 	 * Remove all tags on an object
-	 *
+	 * 
 	 * @param      integer $object_id Object ID
 	 * @return     boolean True on success, false if errors
 	 */
 	public function remove_all_tags($object_id)
 	{
-		if ($object_id > 0)
+		if ($object_id > 0) 
 		{
-			$to = new TagsTableObject($this->_db);
-			if (!$to->removeAllTags($this->_tbl, $object_id))
+			$to = new TagsObject($this->_db);
+			if (!$to->removeAllTags($this->_tbl, $object_id)) 
 			{
 				$this->setError($to->getError());
 				return false;
 			}
 			return true;
-		}
-		else
+		} 
+		else 
 		{
 			return false;
 		}
@@ -328,44 +322,43 @@ class TagsHandler extends JObject
 	/**
 	 * Normalize a tag
 	 * Strips spaces, punctuation, makes lowercase, and allows only alpha-numeric chars
-	 *
+	 * 
 	 * @param      string $tag Raw tag
 	 * @return     string Normalized tag
 	 */
 	public function normalize_tag($tag)
 	{
-		$t = new TagsTableTag($this->_db);
-		return $t->normalize($tag);
+		return strtolower(preg_replace("/[^a-zA-Z0-9]/", '', $tag));
 	}
 
 	/**
 	 * Get the ID of a normalized tag
-	 *
+	 * 
 	 * @param      string $tag Normalized tag
 	 * @return     mixed False if errors, integer on success
 	 */
 	public function get_tag_id($tag)
 	{
-		if (!isset($tag))
+		if (!isset($tag)) 
 		{
 			$this->setError('get_tag_id argument missing');
 			return false;
 		}
 
-		$t = new TagsTableTag($this->_db);
-		$t->loadTag($t->normalize($tag));
+		$t = new TagsTag($this->_db);
+		$t->loadTag($this->normalize_tag($tag));
 		return $t->id;
 	}
 
 	/**
 	 * Get the ID of a raw tag
-	 *
+	 * 
 	 * @param      string $tag Raw tag
 	 * @return     mixed False if errors, integer on success
 	 */
 	public function get_raw_tag_id($tag)
 	{
-		if (!isset($tag))
+		if (!isset($tag)) 
 		{
 			$this->setError('get_raw_tag_id argument missing');
 			return false;
@@ -375,7 +368,7 @@ class TagsHandler extends JObject
 
 	/**
 	 * Get a count of tags
-	 *
+	 * 
 	 * @param      integer $admin     Show admin tags?
 	 * @return     integer
 	 */
@@ -383,17 +376,17 @@ class TagsHandler extends JObject
 	{
 		$filters = array();
 		$filters['by'] = 'user';
-		if ($admin)
+		if ($admin) 
 		{
 			$filters['by'] = 'all';
 		}
-		$t = new TagsTableTag($this->_db);
+		$t = new TagsTag($this->_db);
 		return $t->getCount($filters);
 	}
 
 	/**
 	 * Get a tag cloud for an object
-	 *
+	 * 
 	 * @param      integer $showsizes Show tag size based on use?
 	 * @param      integer $admin     Show admin tags?
 	 * @param      integer $objectid  Object ID
@@ -401,7 +394,7 @@ class TagsHandler extends JObject
 	 */
 	public function get_tag_cloud($showsizes=0, $admin=0, $objectid=NULL)
 	{
-		$t = new TagsTableTag($this->_db);
+		$t = new TagsTag($this->_db);
 		$tags = $t->getCloud($this->_tbl, $admin, $objectid);
 
 		return $this->buildCloud($tags, 'alpha', $showsizes);
@@ -409,7 +402,7 @@ class TagsHandler extends JObject
 
 	/**
 	 * Build a tag cloud
-	 *
+	 * 
 	 * @param      array   $tags      List of tags
 	 * @param      string  $sort      How to sort tags?
 	 * @param      integer $showsizes Show tag size based on use?
@@ -419,12 +412,12 @@ class TagsHandler extends JObject
 	{
 		$html = '';
 
-		if ($tags && count($tags) > 0)
+		if ($tags && count($tags) > 0) 
 		{
 			$min_font_size = 1;
 			$max_font_size = 1.8;
 
-			if ($showsizes)
+			if ($showsizes) 
 			{
 				$retarr = array();
 				foreach ($tags as $tag)
@@ -438,7 +431,7 @@ class TagsHandler extends JObject
 
 				// For ever additional tagged object from min to max, we add $step to the font size.
 				$spread = $max_qty - $min_qty;
-				if (0 == $spread)
+				if (0 == $spread) 
 				{ // Divide by zero
 					$spread = 1;
 				}
@@ -464,21 +457,21 @@ class TagsHandler extends JObject
 				$tag->raw_tag = stripslashes($tag->raw_tag);
 				$tag->raw_tag = str_replace('&amp;', '&', $tag->raw_tag);
 				$tag->raw_tag = str_replace('&', '&amp;', $tag->raw_tag);
-				if ($showsizes == 1)
+				if ($showsizes == 1) 
 				{
 					$size = $min_font_size + ($tag->count - $min_qty) * $step;
-					$tll[$tag->tag] = "\t".'<li' . $class . '><span style="font-size: ' . round($size, 1) . 'em"><a href="' . JRoute::_('index.php?option=com_tags&tag=' . $tag->tag) . '">' . stripslashes($tag->raw_tag) . '</a></li>' . "\n"; //' <span>' . $tag->count . '</span></a></span></li>' . "\n";
-				}
-				elseif ($showsizes == 2)
+					$tll[$tag->tag] = "\t".'<li' . $class . '><span style="font-size: ' . round($size, 1) . 'em"><a href="' . JRoute::_('index.php?option=com_tags&tag=' . $tag->tag) . '">' . stripslashes($tag->raw_tag) . ' <span>' . $tag->count . '</span></a></span></li>' . "\n";
+				} 
+				elseif ($showsizes == 2) 
 				{
-					$tll[$tag->tag] = "\t".'<li' . $class . '><a href="javascript:void(0);" onclick="addtag(\'' . $tag->tag . '\');">' . stripslashes($tag->raw_tag) . '</a></li>' . "\n"; //' <span>' . $tag->count . '</span></a></li>' . "\n";
-				}
-				else
+					$tll[$tag->tag] = "\t".'<li' . $class . '><a href="javascript:void(0);" onclick="addtag(\'' . $tag->tag . '\');">' . stripslashes($tag->raw_tag) . ' <span>' . $tag->count . '</span></a></li>' . "\n";
+				} 
+				else 
 				{
-					$tll[$tag->tag] = "\t".'<li' . $class . '><a href="' . JRoute::_('index.php?option=com_tags&tag=' . $tag->tag) . '">' . stripslashes($tag->raw_tag) . '</a></li>' . "\n"; //' <span>' . $tag->count . '</span></a></li>' . "\n";
+					$tll[$tag->tag] = "\t".'<li' . $class . '><a href="' . JRoute::_('index.php?option=com_tags&tag=' . $tag->tag) . '">' . stripslashes($tag->raw_tag) . ' <span>' . $tag->count . '</span></a></li>' . "\n";
 				}
 			}
-			if ($sort == 'alpha')
+			if ($sort == 'alpha') 
 			{
 				ksort($tll);
 				$html .= implode('', $tll);
@@ -491,7 +484,7 @@ class TagsHandler extends JObject
 
 	/**
 	 * Return a list of tags for an object as a comma-separated string
-	 *
+	 * 
 	 * @param      integer $oid       Object ID
 	 * @param      integer $offset    Record offset
 	 * @param      integer $limit     Number to return
@@ -500,11 +493,11 @@ class TagsHandler extends JObject
 	 * @param      integer $admin     Admin tags?
 	 * @return     string
 	 */
-	public function get_tag_string($oid, $offset=0, $limit=0, $tagger_id=NULL, $strength=0, $admin=0, $label='')
+	public function get_tag_string($oid, $offset=0, $limit=0, $tagger_id=NULL, $strength=0, $admin=0)
 	{
-		$tags = $this->get_tags_on_object($oid, $offset, $limit, $tagger_id, $strength, $admin, $label);
+		$tags = $this->get_tags_on_object($oid, $offset, $limit, $tagger_id, $strength, $admin);
 
-		if ($tags && count($tags) > 0)
+		if ($tags && count($tags) > 0) 
 		{
 			$tagarray = array();
 			foreach ($tags as $tag)
@@ -512,8 +505,8 @@ class TagsHandler extends JObject
 				$tagarray[] = $tag['raw_tag'];
 			}
 			$tags = implode(', ', $tagarray);
-		}
-		else
+		} 
+		else 
 		{
 			$tags = (is_array($tags)) ? implode('', $tags) : '';
 		}
@@ -522,7 +515,7 @@ class TagsHandler extends JObject
 
 	/**
 	 * Turn a comma-separated string of tags into an array of normalized tags
-	 *
+	 * 
 	 * @param      string  $tag_string Comma-separated string of tags
 	 * @param      integer $keep       Use normalized tag as array key
 	 * @return     array
@@ -531,36 +524,25 @@ class TagsHandler extends JObject
 	{
 		$newwords = array();
 
-		if (is_string($tag_string))
+		// If the tag string is empty, return the empty set.
+		if ($tag_string == '') 
 		{
-			// If the tag string is empty, return the empty set.
-			if ($tag_string == '')
-			{
-				return $newwords;
-			}
+			return $newwords;
+		}
 
-			// Perform tag parsing
-			$tag_string = trim($tag_string);
-			$raw_tags = explode(',', $tag_string);
-		}
-		else if (is_array($tag_string))
-		{
-			$raw_tags = $tag_string;
-		}
-		else
-		{
-			throw new \InvalidArgumentException(\JText::sprintf('Tag lsit must be an array or string. Type of "%s" passed.', gettype($tag_string)));
-		}
+		// Perform tag parsing
+		$tag_string = trim($tag_string);
+		$raw_tags = explode(',', $tag_string);
 
 		foreach ($raw_tags as $raw_tag)
 		{
 			$raw_tag = trim($raw_tag);
 			$nrm_tag = $this->normalize_tag($raw_tag);
-			if ($keep != 0)
+			if ($keep != 0) 
 			{
 				$newwords[$nrm_tag] = $raw_tag;
-			}
-			else
+			} 
+			else 
 			{
 				$newwords[] = $nrm_tag;
 			}
