@@ -35,11 +35,68 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Module class for displaying a report problems form
  */
-class modReportProblems extends \Hubzero\Module\Module
+class modReportProblems
 {
+	/**
+	 * Container for properties
+	 * 
+	 * @var array
+	 */
+	private $attributes = array();
+
+	/**
+	 * Constructor
+	 * 
+	 * @param      object $params JParameter
+	 * @param      object $module Database row
+	 * @return     void
+	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Set a property
+	 * 
+	 * @param      string $property Name of property to set
+	 * @param      mixed  $value    Value to set property to
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->attributes[$property] = $value;
+	}
+
+	/**
+	 * Get a property
+	 * 
+	 * @param      string $property Name of property to retrieve
+	 * @return     mixed
+	 */
+	public function __get($property)
+	{
+		if (isset($this->attributes[$property])) 
+		{
+			return $this->attributes[$property];
+		}
+	}
+
+	/**
+	 * Check if a property is set
+	 * 
+	 * @param      string $property Property to check
+	 * @return     boolean True if set
+	 */
+	public function __isset($property)
+	{
+		return isset($this->_attributes[$property]);
+	}
+
 	/**
 	 * Display module content
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function display()
@@ -47,40 +104,31 @@ class modReportProblems extends \Hubzero\Module\Module
 		$this->juser = JFactory::getUser();
 
 		$this->verified = 0;
-		if (!$this->juser->get('guest'))
+		if (!$this->juser->get('guest')) 
 		{
-			$profile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
-			if ($profile->get('emailConfirmed') == 1 || $profile->get('emailConfirmed') == 3)
+			ximport('Hubzero_User_Profile');
+			$profile = Hubzero_User_Profile::getInstance($this->juser->get('id'));
+			if ($profile->get('emailConfirmed') == 1) 
 			{
 				$this->verified = 1;
 			}
 		}
 
-		// Figure out whether this is a guess or temporary account created during the auth_link registration process
-		if ($this->juser->get('guest') || (is_numeric($this->juser->get('username')) && $this->juser->get('username') < 0))
-		{
-			$this->guestOrTmpAccount = true;
-		}
-		else
-		{
-			$this->guestOrTmpAccount = false;
-		}
-
 		$this->referrer = JRequest::getVar('REQUEST_URI','','server');
 		$this->referrer = str_replace('&amp;', '&', $this->referrer);
-		//$this->referrer = str_replace('&', '&amp;', $this->referrer);
-		$this->referrer = base64_encode($this->referrer);
+		$this->referrer = str_replace('&', '&amp;', $this->referrer);
 
-		$browser = new \Hubzero\Browser\Detector();
+		ximport('Hubzero_Browser');
+		$browser = new Hubzero_Browser();
 
-		$this->os = $browser->platform();
-		$this->os_version = $browser->platformVersion();
-		$this->browser = $browser->name();
-		$this->browser_ver = $browser->version();
+		$this->os = $browser->getOs();
+		$this->os_version = $browser->getOsVersion();
+		$this->browser = $browser->getBrowser();
+		$this->browser_ver = $browser->getBrowserVersion();
 
-		$this->css();
-		$this->js();
-		$this->js('jQuery(document).ready(function(jq) { HUB.Modules.ReportProblems.initialize("' . $this->params->get('trigger', '#tab') . '"); });');
+		ximport('Hubzero_Document');
+		Hubzero_Document::addModuleStylesheet($this->module->module);
+		Hubzero_Document::addModuleScript($this->module->module);
 
 		$this->supportParams = JComponentHelper::getParams('com_support');
 
